==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/ie/v20200304/models/MediaJoiningTaskResult.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ie.v20200304.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class MediaJoiningTaskResult extends AbstractModel{

    /**
    * 拼接结果文件。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("File")
    @Expose
    private TaskResultFile File;

    /**
     * Get 拼接结果文件。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return File 拼接结果文件。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public TaskResultFile getFile() {
        return this.File;
    }

    /**
     * Set 拼接结果文件。
注意：此字段可能返回 null，表示取不到有效值。
     * @param File 拼接结果文件。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setFile(TaskResultFile File) {
        this.File = File;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "File.", this.File);

    }
}

==> tencentcloud-sdk-java-3.1.900-sources.jar: com/tencentcloudapi/ie/v20200304/models/MediaJoiningTaskResult.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.ie.v20200304.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class MediaJoiningTaskResult extends AbstractModel {

    /**
    * 拼接结果文件。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("File")
    @Expose
    private TaskResultFile File;

    /**
     * Get 拼接结果文件。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return File 拼接结果文件。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public TaskResultFile getFile() {
        return this.File;
    }

    /**
     * Set 拼接结果文件。
注意：此字段可能返回 null，表示取不到有效值。
     * @param File 拼接结果文件。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setFile(TaskResultFile File) {
        this.File = File;
    }

    public MediaJoiningTaskResult() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public MediaJoiningTaskResult(MediaJoiningTaskResult source) {
        if (source.File != null) {
            this.File = new TaskResultFile(source.File);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "File.", this.File);

    }
}
